@@ -194,6 +194,9 @@ class Recipe(object):
         settings_path = os.path.join(project_dir, 'settings.py')
         settings = open(settings_path, 'r').read()
         
+        # Add the necessary imports
+        settings = 'import os\n' + settings
+        
         # Set default value for TEMPLATE_DIRS setting
         def_template_dirs = '''os.path.join(os.path.dirname(__file__), 'templates')'''
         settings = re.sub(r'(TEMPLATE_DIRS\s?=\s?\()', '\\1\n    %s,' % def_template_dirs,
