@@ -3,6 +3,7 @@ import tempfile
 import os
 import sys
 import shutil
+import imp
 
 import mock
 import zc.buildout.buildout
@@ -17,6 +18,7 @@ from cykooz.djangorecipe import test
 from cykooz.djangorecipe import manage
 
 
+
 class TestRecipe(unittest.TestCase):
 
     def setUp(self):
@@ -372,6 +374,12 @@ class TestRecipe(unittest.TestCase):
         recipe.make_scripts([], [])
         self.assertEqual(open(wsgi_script).readline(), '#!/python5k\n')
 
+    
+    def test_settings_import(self):
+        project_dir = os.path.join(self.buildout_dir, 'project')
+        self.recipe.create_project(project_dir)
+        execfile(os.path.join(project_dir, 'settings.py'), {'__file__': '.'})
+
 
 class ScriptTestCase(unittest.TestCase):
 
